import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// Units appending to the number in legends 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " K" ;


const render = data => {
  //Getting the data for pie chart
  const pieData = pie().sort(null).value(d=>d.United_States)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
// Showing data while hovering on it
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.United_States))
  	.on("mouseover", d => console.log(d.data.United_States));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of years in legends and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.United_States));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Year);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.United_States));
}

// url of gist csv

const csvUrl =
 'https://gist.githubusercontent.com/sampath5/8838065c51fc7161a7638258775e4c67/raw/ddaafbc2fef994f907faae02f651a26b73cd0469/yearwisesales.csv';


//Fetching the data and parsing it using CSV function 
csv(csvUrl).then(csvData => {
    
    if (csvData) {
      render(csvData.slice(0,10));
    }
});